Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(61)

Unified Diff: pkg/front_end/lib/src/incremental/file_state.dart

Issue 2928483005: Add an incremental reloader example and a utility tool to trigger a reload by (Closed)
Patch Set: CL comments Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/front_end/lib/src/incremental/file_state.dart
diff --git a/pkg/front_end/lib/src/incremental/file_state.dart b/pkg/front_end/lib/src/incremental/file_state.dart
index ac7e14ad1e310d7bbfb5e5f542f8d82bc971c059..c3362a411b8ad997d2fa0332ff9ba86f38f4a25a 100644
--- a/pkg/front_end/lib/src/incremental/file_state.dart
+++ b/pkg/front_end/lib/src/incremental/file_state.dart
@@ -221,10 +221,12 @@ class FileSystemState {
_FileSystemView _fileSystemView;
- /// Mapping from file URIs to corresponding [FileState]s.
+ /// Mapping from import URIs to corresponding [FileState]s. For example, this
+ /// may contain an entry for `dart:core`.
final Map<Uri, FileState> _uriToFile = {};
/// Mapping from file URIs to corresponding [FileState]s.
final Map<Uri, FileState> _fileUriToFile = {};
FileSystemState(this.fileSystem, this.uriTranslator);
@@ -237,6 +239,9 @@ class FileSystemState {
return _fileSystemView ??= new _FileSystemView(this);
}
+ /// The `file:` URI of all files currently tracked by this instance.
+ Iterable<Uri> get fileUris => _fileUriToFile.keys;
+
/// Return the [FileState] for the given [absoluteUri], or `null` if the
/// [absoluteUri] cannot be resolved into a file URI.
///
@@ -221,10 +221,12 @@ class FileSystemState {
final Map<Uri, FileState> _uriToFile = {};
- /// Mapping from file URIs to corresponding [FileState]s.
+ /// Mapping from file URIs to corresponding [FileState]s. This map should only
+ /// contain `file:*` URIs as keys.
final Map<Uri, FileState> _fileUriToFile = {};
FileSystemState(this.fileSystem, this.uriTranslator);

Powered by Google App Engine
This is Rietveld 408576698